Index — django-statici18n 0.3.1 documentation

### Navigation

- index
- modules |
- django-statici18n 0.3.1 documentation »

# Index

S | T

## S

statici18n (module) STATICI18N_DOMAIN (in module django.conf.settings) STATICI18N_FILENAME_FUNCTION (in module django.conf.settings) | STATICI18N_OUTPUT_DIR (in module django.conf.settings) STATICI18N_PACKAGES (in module django.conf.settings) STATICI18N_ROOT (in module django.conf.settings)

## T

templatetags.statici18n.statici18n() (in module statici18n)

### Navigation

- index
- modules |
- django-statici18n 0.3.1 documentation »